import { useEffect, useState } from 'react'
import { View, ScrollView, Text } from '@tarojs/components'
import Taro from '@tarojs/taro'
import Banner from '@/components/Banner'
import Notice from '@/components/Notice'
import PageLoading from '@/components/PageLoading'
import { useModel } from '@/store'
import { getApplicationList } from '@/services/dogAPI'
import withBasic from '@/layouts/withBasic'
import MenuItem from './components/MenuItem'

import './style.less'
import { getNoticeList } from '../../services/dogAPI'

const pt16 = {
  paddingTop: '16px'
}

const ml16 = {
  marginLeft: '16px'
}

const IndexPage = (props) => {
  const { pets, cards } = useModel('userData')
  const [totalApplyNum, setTotalApplyNum] = useState(0)
  const [noticeList, setNoticeList] = useState([])
  const banner = [
    { imgUrl: 'https://tse3-mm.cn.bing.net/th/id/OIP-C.yd6uU_V7fqswON8cwWUfewHaE7?w=300&h=200&c=7&r=0&o=5&pid=1.7' },
    { imgUrl: 'https://tse4-mm.cn.bing.net/th/id/OIP-C.A31N2pd7ApUojqrR6x41bwHaFj?pid=ImgDet&rs=1' },
    { imgUrl: 'https://tse1-mm.cn.bing.net/th/id/R-C.413cf61f5c976cdaddafb30e3aeeb547?rik=AJJ41q9z0C1Anw&riu=http%3a%2f%2ffunpicimg.loveinhere.com%2f1008%2f1%2f4770.jpg&ehk=bP4qnBFW9Ha6lXMKKtVhAnkL2hTHv15pjb5oQpAhF6o%3d&risl=&pid=ImgRaw&r=0' },
    { imgUrl: 'https://img.zcool.cn/community/01c62e565d10e76ac7253403cbde61.jpg@1280w_1l_2o_100sh.jpg' }
  ]
  
  useEffect(() => {
    getNoticeList({ pageSize: 5 }).then((res) => {
      console.log('res', res);
      setNoticeList(res.records)
    })
  }, [])

  const goNoticeList = (e) => {

    Taro.navigateTo({ url: '/pages/noticeList/index' })
  }
  const goDetail = (id) => {
    console.log("🚀 ~ file: index.jsx ~ line 52 ~ goNoticeList ~ e", e)

    Taro.navigateTo({ url: `/pages/noticeInfo/index?id=${id}` })
  }

  return (
    <ScrollView scrollY style={{
      height: '100vh'
    }}
    >
      <View className='index-page-box'>
        <View style={{ padding: '16px', boxSizing: 'border-box' }}>
          <Banner banner={banner} />
        </View>
        <View className='border-card-group'>
          <View class='weui-flex'>
            <View class='weui-flex__item'>
              <MenuItem
                icon='dog'
                title='办证申请'
                subtitle='Registration application'
                to='/pages/setDogLicense/index?type=first'
              >
                <View>您有<Text>{ totalApplyNum }</Text>条办证申请记录</View>
              </MenuItem>
            </View>
            <View class='weui-flex__item' style={ml16}>
              <MenuItem
                title='证件查看'
                subtitle='Certificate check'
                icon='certificate'
                to='/pages/dogLicenseList/index'
              >
                <View>您有<Text>{ cards ? cards.length : 0 }</Text>条办证申请记录</View>
              </MenuItem>
            </View>
          </View>
          <View class='weui-flex' style={pt16}>
            <View class='weui-flex__item'>
              <MenuItem
                title='个人中心'
                subtitle='Personal center'
                ratio='470:452'
                icon='personal'
                to='/pages/main/index'
              />
            </View>
            <View class='weui-flex__item' style={ml16}>
              <MenuItem
                title='证件续期'
                subtitle='Certificate renewal'
                ratio='470:206'
                icon='renewal'
                iconSize={72}
                to='/pages/setDogLicense/index?type=renewal'
              />

              <View style={pt16}>
                <MenuItem
                  title='证件补办'
                  subtitle='Replacement certificate'
                  ratio='470:206'
                  icon='replacement'
                  iconSize={72}
                  to='/pages/setDogLicense/index?type=reissue'
                />
              </View>
            </View>
          </View>
        </View>

        <View className='message-box'>
          <Notice NoticeList={noticeList} onMoreClick={goNoticeList} onClick={goDetail} />

        </View>
      </View>
    </ScrollView>
  )
}

export default withBasic(IndexPage, PageLoading)
