import { View, Button, Text, RadioGroup, Picker, Image, Input, Radio, Label, ScrollView } from '@tarojs/components'
import Taro from '@tarojs/taro';
import { useState, useEffect } from 'react';
import Form from '@/components/Form';

import { addDogInfo, getDogInfo, getDogType, setDogInfo } from '../../services/dogAPI';
import { uploadFile } from '../../utils/request';
import './style.less'

export default (props) => {
  const [dogDate, setDogDate] = useState({ birthday: '请选择生日', sex: '请选择性别', petType: '请选择犬种' })
  const [imgUrl, setImgUrl] = useState()
  const [formData, setFormData] = useState()
  const [dogType, setDogType] = useState()
  const petId = Taro.getCurrentInstance().router.params.petId
  useEffect(() => {
    getDogType().then((res) => {
      const DogTypelist = res.content.split(',').map(x => ({ text: x, value: x }))
      setDogType(DogTypelist)
    })

    if (petId) {
      getDogInfo(petId).then((e) => {
        setFormData(e)
        setDogDate(e)
        setImgUrl(e.image)

      })
    }
    return;
  }, [petId])

  const formSubmit = (value) => {
    console.log('formVlue', value);
    if (petId) {
      console.log('y ID',);
      setDogInfo(petId, { ...value, image: imgUrl }).then((e) => {
        Taro.showToast({
          title: '修改成功',
          icon: 'none',
          duration: 1000
        })
        setTimeout(() => {
          Taro.navigateBack({
            delta: 1
          })
        }, 600);
      })
    } else {
      console.log('没有ID',);
      addDogInfo({ ...value, image: imgUrl }).then((e) => {
        Taro.showToast({
          title: '保存成功',
          icon: 'none',
          duration: 1000
        })
        setTimeout(() => {
          Taro.navigateBack({
            delta: 1
          })
        }, 600);

      })
    }

  }
  const onDateChange = (type, value) => {
    console.log('onChange信息选择', type, value);
    switch (type) {
      case 'petSex':
        setDogDate({ ...dogDate, sex: value })

        break;
      case 'birthday':
        setDogDate({ ...dogDate, birthday: value })
        break;
      case 'petType':
        setDogDate({ ...dogDate, petType: value })
        console.log('执行选择犬种---------', value);

        break;
      default:
        break;
    }

  }

  const dogSex = [
    {
      value: 1,
      text: '雄',
    },
    {
      value: 2,
      text: '雌',
    },

  ]


  const addImage = () => {
    Taro.chooseImage({
      count: 1, // 默认9
      sizeType: ['original', 'compressed'], // 可以指定是原图还是压缩图，默认二者都有
      sourceType: ['album', 'camera'], // 可以指定来源是相册还是相机，默认二者都有，在H5浏览器端支持使用 `user` 和 `environment`分别指定为前后摄像头
      success: function (res) {
        // 返回选定照片的本地文件路径列表，tempFilePath可以作为img标签的src属性显示图片
        var tempFilePaths = res.tempFilePaths
        console.log('dogImage', tempFilePaths[0]);
        uploadFile(res.tempFilePaths[0]).then((res2) => {
          console.log("🚀 ~ file: index.jsx ~ line 61 ~ uploadFile ~ res2", res2)
          setImgUrl(res2)
        })
      },
      fail () {
        Taro.showToast({
          title: '上传失败请重试',
          icon: 'error',
          duration: 1000
        })
      }
    })





  }

  return (
    <ScrollView scrollY style={{ height: '100vh' }}>
      <View class='page' >
        <Form onSubmit={formSubmit}    >
          <mp-form models={formData}  >
            <mp-cells title=''>
              <mp-cell title='狗狗名称' extClass=''>
                <Input value={formData?.name} name='name' placeholder='请输入狗狗名称' />
              </mp-cell>
              <mp-cell title='狗狗性别' extClass=''>
                <s-picker name='sex' rangeKey='text' rangeValue='value' range={dogSex} value={dogDate.sex} />

                {/* <Picker name='sex' mode='selector' range={selector} onChange={(e) => { onDateChange('petSex', e.detail.data.value) }}>
                  <View className='picker'>
                    {dogDate.sex == 1 ? '雄' : dogDate.sex == 2 ? '雌' : dogDate.sex}
                  </View>
                </Picker> */}
              </mp-cell>
              <mp-cell title='犬种' extClass=''>
                <s-picker name='petType' rangeKey='text' rangeValue='value' range={dogType} value={dogDate.petType} />

                {/* <Picker name='petType' mode='selector' range={dogType} onChange={(e) => { onDateChange('petType', e.detail.data.value) }}>
                  <View className='picker'>
                    {dogDate.petType}
                  </View>
                </Picker> */}
              </mp-cell>
              <mp-cell title='生日' extClass=''>
                <Picker name='birthday' mode='date' onChange={(e) => { onDateChange('birthday', e.detail.value) }}>
                  <View className='picker'>
                    {dogDate.birthday}
                  </View>
                </Picker>
              </mp-cell>
              <mp-cell title='毛色' extClass=''>
                <Input name='color' placeholder='请输入毛色' value={formData?.color} />
              </mp-cell>
              <mp-cell title='狗狗照片' extClass=''>
                {
                  !imgUrl ?
                    <View className='addDogImage' onClick={addImage} >
                      <Text>+</Text>
                    </View>
                    :
                    <Image className='dogImage' name='image' src={imgUrl} onClick={addImage} />
                }
              </mp-cell>
            </mp-cells>
          </mp-form>
          <View slot='button' style={{ margin: '4em 0 2em 0' }}>
            <Button style={{ backgroundColor: '#fbd804', borderRadius: '40px', color: '#000', border: '0px' }} class='weui-btn' type='primary' loading={false} formType='submit'>确定</Button>
          </View>
        </Form>
      </View>
    </ScrollView >
  )
}




